@@ -1,5 +1,5 @@
 /*
- * Copyright 2024 The Phosh Developers
+ * Copyright 2024-2025 Phosh.mobi e.V.
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -61,12 +61,12 @@ pub fn folder_to_icon_name(file: gio::File) -> &'static str {
         _ => {}
     }
 
-    let home = gio::File::for_path(&glib::home_dir());
+    let home = gio::File::for_path(glib::home_dir());
     if home.equal(&file) {
         return "user-home-symbolic";
     }
 
-    for (dir, icon) in SPECIAL_DIRS.iter() {
+    for (dir, icon) in &SPECIAL_DIRS {
         let Some(dir) = glib::user_special_dir(*dir) else {
             continue;
         };
@@ -88,3 +88,13 @@ pub fn is_valid_folder(folder: &Option<gio::File>) -> bool {
 
     folder.as_ref().unwrap().path().is_some()
 }
+
+pub fn is_schema_installed() -> bool {
+    let source = gio::SettingsSchemaSource::default();
+    if source.is_none() {
+        return false;
+    }
+    let source = source.unwrap();
+
+    source.lookup("mobi.phosh.FileSelector", true).is_some()
+}
